These parameters are auxiliary to decision tree models that use the
"rpartScore" engine. They correspond to tuning parameters that would be
specified using set_engine("rpartScore", ...).
Value
An object of S3 parent class param and primary class qual_param;
see dials::new_qual_param().
Details
split_func and prune_func are dials for split and prune,
respectively. See ?rpartScore::rpartScore for more details on the
original parameters. These parameters are engine-specific, not general to
decision tree models, so are provided here rather than in dials.